@@ -10,10 +10,11 @@ def main():
     parser.add_argument('database', help='database to run queries on')
     parser.add_argument('table', help='table to insert into (will create new if doesn\'t exist)')
     parser.add_argument('filename', help='filepath of CSV file to insert')
+    parser.add_argument('--overwrite', action='store_true', 'help='Overwrite already-present table in database')
     args = parser.parse_args()
 
     # create session for login
     sess = Session.Session(args.user, args.password, args.host, db=args.database)
 
     # use insert_from_CSV() method to insert csv into table
-    sess.insert_from_CSV(args.filename, args.table)
\ No newline at end of file
+    sess.insert_from_CSV(args.filename, args.table, args.overwrite)
\ No newline at end of file
